@@ -19,7 +19,6 @@ class _Tls(local):
 
   """Thread local storage for the project state."""
   
-  _state = {}
   _current_project = None
 
 _tls = _Tls()
@@ -39,6 +38,9 @@ class Project(object):
   
   """
 
+  __state = {}
+  __registered = False
+
   config = {
     'PROJECT': {
       'NAME': '',
@@ -65,9 +67,10 @@ class Project(object):
 
   def __init__(self, config_path=None, make=True):
 
-    self.__dict__ = _tls._state
+    self.__dict__ = self.__state
+    _tls._current_project = self
 
-    if _tls._current_project is None:
+    if not self.__registered:
 
       if config_path is None:
         raise ProjectImportError('Project instantiation outside the Flasker '
@@ -102,7 +105,7 @@ class Project(object):
       self._extensions = []
       self._before_startup = []
 
-      _tls._current_project = self
+      self.__registered = True
 
       if make:
         self._make()
@@ -190,7 +193,7 @@ class Project(object):
 
 
 def _get_current_project():
-  return _tls._current_project
+  return _tls._current_project or Project()
 
 current_project = LocalProxy(_get_current_project)
 
